@@ -77,9 +77,6 @@ DESCRIPTION
                 hiding the section; 
                 the default is None
 
-    (NB String arguments don't need to be quoted unless they contain spaces or
-        special characters)
-                 
     The (leading) arguments can also be given positionally, in the order of
     the keyword arguments above, e.g.
 
@@ -194,7 +191,7 @@ EXTENDED DESCRIPTION
 
  seesaw 
  
-   By setting the option 'seesaw' to False it is possible to apply SeeSaw to
+    By setting the option 'seesaw' to False it is possible to apply SeeSaw to
     non-SeeSaw sections, e.g. the div created by the TableOfContents macro. In
     such a case, the section name in the SeeSaw call should be a class already
     attached to the div, or the class can be added as an extra name or by use
@@ -237,9 +234,13 @@ EXAMPLES
     Download seesawexamples.tgz from http://moinmo.in/Macromarket/SeeSaw
 
 AUTHOR
-    Jim Wight <j.k.wight@gmail.com>
+    Jim Wight <jkwight@gmail.com>
 
 HISTORY
+    [v1.4] 2013-04-28
+    Support both execute (Moin 1.6) and macro_MacroName (1.7+) interfaces
+    Make loading of JavaScript configurable
+
     [v1.3] 2013-03-31
     Treat additional plain section names as added classes
     Embed image data
@@ -277,8 +278,18 @@ HISTORY
 '''
 
 
-#--- Configuration ----------------------------------------
+#--- Configuration --------------------------------------------
 # 
+jqueryjs = 'http://code.jquery.com/jquery-1.9.1.min.js'      # No installation required
+# jqueryjs = '/jscript/jquery.js'                            # Or similar to load from a local file 
+# jqueryjs = None                                            # If jquery being loaded via html_head
+#                                                            # See INSTALL.html
+#
+seesawjs = ''                                                # No installation required
+# seesawjs = '/jscript/seesaw.js'                            # Or similar to load from a local file
+# seesawjs = None                                            # If seesaw.js being loaded via html_head
+#                                                            # See INSTALL.html
+#
 # Change this to extend the list of image sets, either as base64
 # encodings or as filenames ('show' image first, in both cases) e.g.
 #
@@ -294,13 +305,51 @@ moreimages = dict(
 imageprefix = "/img"
 #
 #
-#--- End of Configuration ---------------------------------
+#--- End of Configuration -------------------------------------
 
+
+from MoinMoin import wikiutil
 Dependencies = []
+pagename = ''
 
+# MoinMoin 1.7 and later interface
+def macro_SeeSaw(macro, section=u'section', toshow=unicode, tohide=unicode, show=False, bg=unicode, inline=unicode, image=unicode, speed=u'0', seesaw=True, addclass=u'', type=(u'link',u'button'), effect=(u'dflt',u'slide', u'fade')):
+    # Compensate for lack of single-quoted argument support
+    def squote(item):
+        if item in (None, True, False): return item
+        return item.lstrip("'").rstrip("'")
+
+    html = SeeSaw(macro, map(squote,(section,toshow,tohide,show,bg,inline,image,speed,seesaw,addclass,type,effect))) 
+
+    return macro.formatter.rawHTML(html)
+
+
+# Pre MoinMoin 1.7 interface
 def execute(macro, args):
-    from MoinMoin import wikiutil
+    parser = wikiutil.ParameterParser('%(section)s%(toshow)s%(tohide)s%(show)b%(bg)s%(inline)s%(image)s%(speed)s%(seesaw)b%(addclass)s%(type)s%(effect)s')
+    count, params = parser.parse_parameters(args)
+    section, toshow, tohide, show, bgnd, inline, image, speed, seesaw, addclass, control, effect = (params[x] for x in ('section', 'toshow', 'tohide', 'show', 'bg', 'inline', 'image', 'speed', 'seesaw', 'addclass', 'type', 'effect'))
+
+    if section is None:
+        section = 'section'
+        
+    if speed is None:
+        speed = 0
+
+    if addclass is None:
+        addclass = ""
+
+    if effect not in ['slide', 'fade']:
+        effect = 'dflt'
+
+    html = SeeSaw(macro, (section, toshow, tohide, show, bgnd, inline, image, speed, seesaw, addclass, control, effect))
+
+    return macro.formatter.rawHTML(html) 
+
+
+def SeeSaw(macro, (section, toshow, tohide, show, bgnd, inline, image, speed, seesaw, addclass, control, effect)):
     import re
+    global pagename
 
     def escape(arg):
         if arg is None:
@@ -326,16 +375,6 @@ phCliIWAtYzoihgpso4oRYw43IICAElFBRBz9sLvAAAAAElFTkSuQmCC
 )
     images.update(moreimages)
 
-    effects = ['default', 'slide', 'fade']
-
-    parser = wikiutil.ParameterParser('%(section)s%(toshow)s%(tohide)s%(show)b%(bg)s%(inline)s%(image)s%(speed)s%(seesaw)b%(addclass)s%(type)s%(effect)s')
-    (count, params) = parser.parse_parameters(args)
-    (section, toshow, tohide, show, bgnd, inline, image, speed, seesaw, addclass, control, effect) = \
-        (params[x] for x in ('section', 'toshow', 'tohide', 'show', 'bg', 'inline', 'image', 'speed', 'seesaw', 'addclass', 'type', 'effect'))
-
-    if section is None:
-        section = 'section'
-
     if tohide is None and toshow is None:
         if inline is None:
             toshow = 'Show'; tohide = 'Hide'
@@ -346,41 +385,28 @@ phCliIWAtYzoihgpso4oRYw43IICAElFBRBz9sLvAAAAAElFTkSuQmCC
     elif toshow is None and tohide is not None:
         toshow = tohide
 
-    if show is None:
-        show = False
-
-    if image is not None:
+    if image:
         imagepair = images.get(image)
-        if imagepair is not None:
+        if imagepair:
             if not imagepair[0].startswith("data:image"):
                 imagepair = (imageprefix.rstrip("/") + "/" + x for x in imagepair)
             (toshow, tohide) = ('''<img src="%s" style="vertical-align:middle"/>''' % x for x in imagepair)
 
-    if speed is None:
-        speed = 0
     try:
         speed = int(speed)
     except ValueError:
         speed = "'%s'" % speed
 
-    if seesaw is None or seesaw:
-        seesaw = 'true'
+    if seesaw:
+        seesaw = 'true' 
     else:
         seesaw = 'false'
 
-    if addclass is None:
-        addclass = ""
-
     if control == 'button':
         opentag = closetag = 'button'
     else:
         opentag = 'a href=""'; closetag = 'a'
 
-    if effect not in effects:
-        effect = effects[0]
-    if (effect == 'default'):
-        effect = 'dflt'
-
     sections = ' '.join(section.strip().replace(' ', '/').split('/')).split()
     plain = [x.encode("iso-8859-1") for x in sections if not re.compile(r'^[%+-].*').match(x)]
     toggles = [x.lstrip('%').encode("iso-8859-1") for x in sections if x.startswith('%')]
@@ -404,14 +430,14 @@ phCliIWAtYzoihgpso4oRYw43IICAElFBRBz9sLvAAAAAElFTkSuQmCC
         prehd, tohide, posthd = matches.groups()
 
     section, preshw, postshw, prehd, posthd, bgnd, inline = (escape(x) for x in (section, preshw, postshw, prehd, posthd, bgnd, inline))
-    if image is None:
+    if not image:
         toshow = escape(toshow); tohide = escape(tohide)
 
-    if inline is None:
+    if not inline:
         inlinesection = ""
     else:
         inlineopts = ""
-        if bgnd is not None:
+        if bgnd:
             inlineopts += ''' %s-bg''' % section
         if show:
             inlineopts += " show"
@@ -436,7 +462,7 @@ phCliIWAtYzoihgpso4oRYw43IICAElFBRBz9sLvAAAAAElFTkSuQmCC
         if posthd: 
             posthide = prepost % (hidepart, hidestyle, posthd)
         hidepart = '''<span class="%(hidepart)s" %(hidestyle)s>%(tohide)s</span>''' % locals()
-        if bgnd is not None:
+        if bgnd:
             bgdata = '''data-section="%(section)s" data-bg="%(bgnd)s"''' % locals()
         else:
             bgdata = ""
@@ -457,4 +483,45 @@ phCliIWAtYzoihgpso4oRYw43IICAElFBRBz9sLvAAAAAElFTkSuQmCC
 %(inlinesection)s
 ''' % locals()
 
-    return macro.formatter.rawHTML(html)
+    if  macro.formatter.page.page_name != pagename:
+        pagename = macro.formatter.page.page_name
+        html = SeeSawJS(jqueryjs,seesawjs) + html
+
+    return html
+
+
+def SeeSawJS(jquery, seesaw):
+    antijump = '''
+<style type="text/css">
+div.seesaw, span.seesaw, table.seesaw, tr.seesaw, td.seesaw { display: none; }
+div.seesaw.show { display: block; }
+span.seesaw.show { display: inline; }
+table.seesaw.show { display: table; }
+tr.seesaw.show { display: table-row; }
+td.seesaw.show { display: table-cell; }
+</style>
+'''
+
+    if seesaw is None:
+        if jquery is None:
+            return antijump
+	else:	   
+	    return '<p><span style="font-size:150%;color:red">Incompatible configuration combination of jquery and seesaw</p>'
+
+    if jquery is None:
+        jqueryjs = ''
+    else:	
+        jqueryjs = '''
+<script type="text/javascript" src="%s"></script>
+''' % jquery
+
+    if seesaw:
+	seesawjs = '''
+<script type="text/javascript" src="%s"></script>
+''' % seesaw
+    else:
+	seesawjs = '''
+<script type="text/javascript">var seesawc,seesaws,seesawfx={toggle:{slide:"slideToggle",fade:"fadeToggle",show:"toggle",hide:"toggle"},show:{slide:"slideDown",fade:"fadeIn",show:"hide",hide:"show"},hide:{slide:"slideUp",fade:"fadeOut",show:"show",hide:"hide"}};function seeSaw(f,b,e,a){var d,c;$.each(["toggle","show","hide"],function(){c=seesawfx[this];c.dflt=this;$.each(f[this],function(){seesawc.filter((d="."+this)).find(".part").not(".seesawed").addClass("seesawed").filter(".show")[c.show]().end().filter(".hide")[c.hide]();(a?seesaws.filter(d):$(d)).not(".seesawc,.seesawed").addClass("seesawed").each(function(){e?$(this)[c[b]](e):$(this)[c[b]]()})})});$(".seesawed").removeClass("seesawed")}$(document).ready(function(){var a;(seesaws=$(".seesaw")).not(".show").hide();(seesawc=$(".seesawc")).each(function(){if((a=$(this).data())){seesaws.filter("."+a.section+"-bg").css("background-color",a.bg)}})});</script>
+'''
+
+    return antijump + jqueryjs + seesawjs
